.. include:: ../README.rst
   :start-line: 0
   :end-line: 52

.. image:: _static/detect.gif

.. include:: ../README.rst
   :start-line: 61

Table of Contents
=================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   pipeline
   tutorials
   examples
   contributing
   authors
   changelog
   citing

.. toctree::
    :maxdepth: 1
    :caption: API:

    module-preprocessing
    module-data
    module-detect

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
